+{
   locale_version => 1.20,
   entry => <<'ENTRY', # for DUCET v8.0.0
0982      ; [.2640.0020.0002][.FFF1.0000.0000] # BENGALI SIGN ANUSVARA
0981      ; [.2640.0020.0002][.FFF2.0000.0000] # BENGALI SIGN CANDRABINDU
0983      ; [.2640.0020.0002][.FFF3.0000.0000] # BENGALI SIGN VISARGA
0994      ; [.2640.0020.0002][.FFF0.0000.0000] # BENGALI LETTER AU
09CE      ; [.2650.0020.0002][.FFF0.0000.0000] # BENGALI LETTER KHANDA TA
09A4 09CD 200D ; [.2650.0020.0002][.FFF0.0000.0000] # <BENGALI LETTER TA, BENGALI SIGN VIRAMA, ZERO WIDTH JOINER>
09A4      ; [.2650.0020.0002][.FFF1.0000.0000] # BENGALI LETTER TA
0995 09CD 09B7 ; [.2662.0020.0002][.FFF1.0000.0000] # <BENGALI LETTER KA, BENGALI SIGN VIRAMA, BENGALI LETTER SSA>
09B9      ; [.2662.0020.0002][.FFF0.0000.0000] # BENGALI LETTER HA
ENTRY
};
